{
  description = "Various packages not in nixpkgs";

  inputs.nixpkgs.url = "github:NixOS/nixpkgs/nixos-unstable";

  outputs =
    { self, nixpkgs }:
    let
      allSystems = [
        "x86_64-linux"
        "aarch64-linux"
        "x86_64-darwin"
        "aarch64-darwin"
      ];
      forAllSystems =
        f:
        nixpkgs.lib.genAttrs allSystems (
          system:
          f {
            pkgs = import nixpkgs {
              inherit system;
              config.allowUnfree = true;
            };
          }
        );
    in
    {
      overlays = {
        default = final: prev: {
          awakened-poe-trade = self.packages.${prev.system}.awakened-poe-trade;
          path-of-building-beta = self.packages.${prev.system}.path-of-building-beta;
          vintagestory-unstable = self.packages.${prev.system}.vintagestory-unstable;
        };
        awakened-poe-trade = final: prev: {
          awakened-poe-trade = self.packages.${prev.system}.awakened-poe-trade;
        };
        path-of-building-beta = final: prev: {
          awakened-poe-trade = self.packages.${prev.system}.path-of-building-beta;
        };
        vintagestory-unstable = final: prev: {
          vintagestory-unstable = self.packages.${prev.system}.vintagestory-unstable;
        };
        noita-entangled-worlds = final: prev: {
          noita-entangled-worlds = self.packages.${prev.system}.noita-entangled-worlds;
        };
      };

      packages = forAllSystems (
        { pkgs }:
        {
          awakened-poe-trade = pkgs.callPackage ./pkgs/awakened-poe-trade { };
          path-of-building-beta = pkgs.qt6Packages.callPackage ./pkgs/path-of-building-beta { };
          path-of-building-poe2 = pkgs.qt6Packages.callPackage ./pkgs/path-of-building-poe2 { };
          vintagestory-unstable = pkgs.callPackage ./pkgs/vintagestory { };
          noita-entangled-worlds = pkgs.callPackage ./pkgs/noita-entangled-worlds { };
        }
      );
    };
}
